==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-faq-light/dictionaries/tr.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Izzet Sirin <izzet.sirin@htr.com.tr>
 *
 */
Dict::Add('TR TR', 'Turkish', 'Türkçe', [
	'Brick:Portal:FAQ:Menu' => 'SSS',
	'Brick:Portal:FAQ:Title' => 'Sıkça Sorulan Sorular',
	'Brick:Portal:FAQ:Title+' => '<p>In a hurry?</p><p>Check out the list of most common questions and (maybe) find the expected answer right away.</p>~~',
	'Class:FAQ' => 'SSS',
	'Class:FAQ+' => 'Sıkça Sorulan Sorular',
	'Class:FAQ/Attribute:category_id' => 'Kategori',
	'Class:FAQ/Attribute:category_id+' => '~~',
	'Class:FAQ/Attribute:category_name' => 'Kategori Adı',
	'Class:FAQ/Attribute:category_name+' => '~~',
	'Class:FAQ/Attribute:description' => 'Açıklama',
	'Class:FAQ/Attribute:description+' => '~~',
	'Class:FAQ/Attribute:domains' => 'Domains~~',
	'Class:FAQ/Attribute:error_code' => 'Hata Kodu',
	'Class:FAQ/Attribute:error_code+' => '~~',
	'Class:FAQ/Attribute:key_words' => 'Anahtar Kelimeler',
	'Class:FAQ/Attribute:key_words+' => '~~',
	'Class:FAQ/Attribute:summary' => 'Özet',
	'Class:FAQ/Attribute:summary+' => '~~',
	'Class:FAQ/Attribute:title' => 'Başlık',
	'Class:FAQ/Attribute:title+' => '~~',
	'Class:FAQCategory' => 'SSS Kategori',
	'Class:FAQCategory+' => 'SSS için kategori',
	'Class:FAQCategory/Attribute:faq_list' => 'SSS',
	'Class:FAQCategory/Attribute:faq_list+' => 'Bu kategoriyle ilgili tüm sık sorulan sorular',
	'Class:FAQCategory/Attribute:name' => 'İsim',
	'Class:FAQCategory/Attribute:name+' => '~~',
	'Menu:FAQ' => 'SSS',
	'Menu:FAQ+' => 'Tüm SSS',
	'Menu:FAQCategory' => 'SSS kategorileri',
	'Menu:FAQCategory+' => 'Tüm SSS kategorileri',
	'Menu:Problem:Shortcuts' => 'Kısayollar',
	'Menu:ProblemManagement' => 'Problem yönetimi',
	'Menu:ProblemManagement+' => 'Problem yönetimi',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-faq-light/dictionaries/tr.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Izzet Sirin <izzet.sirin@htr.com.tr>
 *
 */
Dict::Add('TR TR', 'Turkish', 'Türkçe', array(
	'Class:FAQ' => 'SSS',
	'Class:FAQ+' => 'Sıkça Sorulan Sorular',
	'Class:FAQ/Attribute:title' => 'Başlık',
	'Class:FAQ/Attribute:title+' => '~~',
	'Class:FAQ/Attribute:summary' => 'Özet',
	'Class:FAQ/Attribute:summary+' => '~~',
	'Class:FAQ/Attribute:description' => 'Açıklama',
	'Class:FAQ/Attribute:description+' => '~~',
	'Class:FAQ/Attribute:category_id' => 'Kategori',
	'Class:FAQ/Attribute:category_id+' => '~~',
	'Class:FAQ/Attribute:category_name' => 'Kategori Adı',
	'Class:FAQ/Attribute:category_name+' => '~~',
	'Class:FAQ/Attribute:error_code' => 'Hata Kodu',
	'Class:FAQ/Attribute:error_code+' => '~~',
	'Class:FAQ/Attribute:key_words' => 'Anahtar Kelimeler',
	'Class:FAQ/Attribute:key_words+' => '~~',
	'Class:FAQ/Attribute:domains' => 'Domains~~',
));

//
// Class: FAQCategory
//

Dict::Add('TR TR', 'Turkish', 'Türkçe', array(
	'Class:FAQCategory' => 'SSS Kategori',
	'Class:FAQCategory+' => 'SSS için kategori',
	'Class:FAQCategory/Attribute:name' => 'İsim',
	'Class:FAQCategory/Attribute:name+' => '~~',
	'Class:FAQCategory/Attribute:faq_list' => 'SSS',
	'Class:FAQCategory/Attribute:faq_list+' => 'Bu kategoriyle ilgili tüm sık sorulan sorular',
));
Dict::Add('TR TR', 'Turkish', 'Türkçe', array(
	'Menu:ProblemManagement' => 'Problem yönetimi',
	'Menu:ProblemManagement+' => 'Problem yönetimi',
	'Menu:Problem:Shortcuts' => 'Kısayollar',
	'Menu:FAQCategory' => 'SSS kategorileri',
	'Menu:FAQCategory+' => 'Tüm SSS kategorileri',
	'Menu:FAQ' => 'SSS',
	'Menu:FAQ+' => 'Tüm SSS',
	'Brick:Portal:FAQ:Menu' => 'SSS',
	'Brick:Portal:FAQ:Title' => 'Sıkça Sorulan Sorular',
	'Brick:Portal:FAQ:Title+' => '<p>In a hurry?</p><p>Check out the list of most common questions and (maybe) find the expected answer right away.</p>~~',
));
